@@ -17,6 +17,6 @@ class CxCreateNewScanResponse(object):
         self.link = link
 
     def __str__(self):
-        return "CxCreateNewScanResponse(scan_id={}, link={})".format(
+        return "CxCreateNewScanResponse(id={}, link={})".format(
             self.id, self.link
         )
